@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of Radicale Server - Calendar Server
-# Copyright © 2008-2012 Guillaume Ayoub
+# Copyright © 2008-2015 Guillaume Ayoub
 # Copyright © 2008 Nicolas Kandel
 # Copyright © 2008 Pascal Halter
 #
@@ -45,18 +45,26 @@ INITIAL_CONFIG = {
         "ssl": "False",
         "certificate": "/etc/apache2/ssl/server.crt",
         "key": "/etc/apache2/ssl/server.key",
-        "dns_lookup": "True"},
+        "protocol": "PROTOCOL_SSLv23",
+        "ciphers": "",
+        "dns_lookup": "True",
+        "base_prefix": "/",
+        "can_skip_base_prefix": "False",
+        "realm": "Radicale - Password Required"},
+    "well-known": {
+         "caldav": "/%(user)s/caldav/",
+         "carddav": "/%(user)s/carddav/"},
     "encoding": {
         "request": "utf-8",
         "stock": "utf-8"},
-    "acl": {
+    "auth": {
         "type": "None",
-        "public_users": "public",
-        "private_users": "private",
+        "custom_handler": "",
         "htpasswd_filename": "/etc/radicale/users",
         "htpasswd_encryption": "crypt",
-        "imap_auth_host_name": "localhost",
-        "imap_auth_host_port": "143",
+        "imap_hostname": "localhost",
+        "imap_port": "143",
+        "imap_ssl": "False",
         "ldap_url": "ldap://localhost:389/",
         "ldap_base": "ou=users,dc=example,dc=com",
         "ldap_attribute": "uid",
@@ -65,13 +73,22 @@ INITIAL_CONFIG = {
         "ldap_password": "",
         "ldap_scope": "OneLevel",
         "pam_group_membership": "",
-        "courier_socket": ""},
+        "courier_socket": "",
+        "http_url": "",
+        "http_user_parameter": "",
+        "http_password_parameter": ""},
+    "git": {
+        "committer": "Radicale <radicale@example.com>"},
+    "rights": {
+        "type": "None",
+        "custom_handler": "",
+        "file": "~/.config/radicale/rights"},
     "storage": {
         "type": "filesystem",
+        "custom_handler": "",
         "filesystem_folder": os.path.expanduser(
             "~/.config/radicale/collections"),
-        "git_folder": os.path.expanduser(
-            "~/.config/radicale/collections")},
+        "database_url": ""},
     "logging": {
         "config": "/etc/radicale/logging",
         "debug": "False",
